@@ -1,4 +1,6 @@
-/* GIO - GLib Input, Output and Streaming Library
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/*
+ * GIO - GLib Input, Output and Streaming Library
  *
  * Copyright 2009 Red Hat, Inc
  *
@@ -29,12 +31,6 @@
 #include "gtlscertificate-gnutls.h"
 #include <glib/gi18n-lib.h>
 
-static void     g_tls_certificate_gnutls_initable_iface_init (GInitableIface  *iface);
-
-G_DEFINE_TYPE_WITH_CODE (GTlsCertificateGnutls, g_tls_certificate_gnutls, G_TYPE_TLS_CERTIFICATE,
-			 G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
-						g_tls_certificate_gnutls_initable_iface_init);)
-
 enum
 {
   PROP_0,
@@ -46,7 +42,7 @@ enum
   PROP_ISSUER
 };
 
-struct _GTlsCertificateGnutlsPrivate
+typedef struct
 {
   gnutls_x509_crt_t cert;
   gnutls_x509_privkey_t key;
@@ -57,32 +53,41 @@ struct _GTlsCertificateGnutlsPrivate
 
   guint have_cert : 1;
   guint have_key  : 1;
-};
+} GTlsCertificateGnutlsPrivate;
+
+static void     g_tls_certificate_gnutls_initable_iface_init (GInitableIface  *iface);
+
+G_DEFINE_TYPE_WITH_CODE (GTlsCertificateGnutls, g_tls_certificate_gnutls, G_TYPE_TLS_CERTIFICATE,
+                         G_ADD_PRIVATE (GTlsCertificateGnutls);
+                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
+                                                g_tls_certificate_gnutls_initable_iface_init);)
 
 static void
 g_tls_certificate_gnutls_finalize (GObject *object)
 {
   GTlsCertificateGnutls *gnutls = G_TLS_CERTIFICATE_GNUTLS (object);
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
 
-  gnutls_x509_crt_deinit (gnutls->priv->cert);
-  if (gnutls->priv->key)
-    gnutls_x509_privkey_deinit (gnutls->priv->key);
+  gnutls_x509_crt_deinit (priv->cert);
+  if (priv->key)
+    gnutls_x509_privkey_deinit (priv->key);
 
-  if (gnutls->priv->issuer)
-    g_object_unref (gnutls->priv->issuer);
+  if (priv->issuer)
+    g_object_unref (priv->issuer);
 
-  g_clear_error (&gnutls->priv->construct_error);
+  g_clear_error (&priv->construct_error);
 
   G_OBJECT_CLASS (g_tls_certificate_gnutls_parent_class)->finalize (object);
 }
 
 static void
 g_tls_certificate_gnutls_get_property (GObject    *object,
-				       guint       prop_id,
-				       GValue     *value,
-				       GParamSpec *pspec)
+                                       guint       prop_id,
+                                       GValue     *value,
+                                       GParamSpec *pspec)
 {
   GTlsCertificateGnutls *gnutls = G_TLS_CERTIFICATE_GNUTLS (object);
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
   GByteArray *certificate;
   char *certificate_pem;
   int status;
@@ -92,51 +97,51 @@ g_tls_certificate_gnutls_get_property (GObject    *object,
     {
     case PROP_CERTIFICATE:
       size = 0;
-      status = gnutls_x509_crt_export (gnutls->priv->cert,
-				       GNUTLS_X509_FMT_DER,
-				       NULL, &size);
+      status = gnutls_x509_crt_export (priv->cert,
+                                       GNUTLS_X509_FMT_DER,
+                                       NULL, &size);
       if (status != GNUTLS_E_SHORT_MEMORY_BUFFER)
-	certificate = NULL;
+        certificate = NULL;
       else
-	{
-	  certificate = g_byte_array_sized_new (size);
-	  certificate->len = size;
-	  status = gnutls_x509_crt_export (gnutls->priv->cert,
-					   GNUTLS_X509_FMT_DER,
-					   certificate->data, &size);
-	  if (status != 0)
-	    {
-	      g_byte_array_free (certificate, TRUE);
-	      certificate = NULL;
-	    }
-	}
+        {
+          certificate = g_byte_array_sized_new (size);
+          certificate->len = size;
+          status = gnutls_x509_crt_export (priv->cert,
+                                           GNUTLS_X509_FMT_DER,
+                                           certificate->data, &size);
+          if (status != 0)
+            {
+              g_byte_array_free (certificate, TRUE);
+              certificate = NULL;
+            }
+        }
       g_value_take_boxed (value, certificate);
       break;
 
     case PROP_CERTIFICATE_PEM:
       size = 0;
-      status = gnutls_x509_crt_export (gnutls->priv->cert,
-				       GNUTLS_X509_FMT_PEM,
-				       NULL, &size);
+      status = gnutls_x509_crt_export (priv->cert,
+                                       GNUTLS_X509_FMT_PEM,
+                                       NULL, &size);
       if (status != GNUTLS_E_SHORT_MEMORY_BUFFER)
-	certificate_pem = NULL;
+        certificate_pem = NULL;
       else
-	{
-	  certificate_pem = g_malloc (size);
-	  status = gnutls_x509_crt_export (gnutls->priv->cert,
-					   GNUTLS_X509_FMT_PEM,
-					   certificate_pem, &size);
-	  if (status != 0)
-	    {
-	      g_free (certificate_pem);
-	      certificate_pem = NULL;
-	    }
-	}
+        {
+          certificate_pem = g_malloc (size);
+          status = gnutls_x509_crt_export (priv->cert,
+                                           GNUTLS_X509_FMT_PEM,
+                                           certificate_pem, &size);
+          if (status != 0)
+            {
+              g_free (certificate_pem);
+              certificate_pem = NULL;
+            }
+        }
       g_value_take_string (value, certificate_pem);
       break;
 
     case PROP_ISSUER:
-      g_value_set_object (value, gnutls->priv->issuer);
+      g_value_set_object (value, priv->issuer);
       break;
 
     default:
@@ -146,11 +151,12 @@ g_tls_certificate_gnutls_get_property (GObject    *object,
 
 static void
 g_tls_certificate_gnutls_set_property (GObject      *object,
-				       guint         prop_id,
-				       const GValue *value,
-				       GParamSpec   *pspec)
+                                       guint         prop_id,
+                                       const GValue *value,
+                                       GParamSpec   *pspec)
 {
   GTlsCertificateGnutls *gnutls = G_TLS_CERTIFICATE_GNUTLS (object);
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
   GByteArray *bytes;
   const char *string;
   gnutls_datum_t data;
@@ -161,108 +167,108 @@ g_tls_certificate_gnutls_set_property (GObject      *object,
     case PROP_CERTIFICATE:
       bytes = g_value_get_boxed (value);
       if (!bytes)
-	break;
-      g_return_if_fail (gnutls->priv->have_cert == FALSE);
+        break;
+      g_return_if_fail (priv->have_cert == FALSE);
       data.data = bytes->data;
       data.size = bytes->len;
-      status = gnutls_x509_crt_import (gnutls->priv->cert, &data,
-				       GNUTLS_X509_FMT_DER);
+      status = gnutls_x509_crt_import (priv->cert, &data,
+                                       GNUTLS_X509_FMT_DER);
       if (status == 0)
-	gnutls->priv->have_cert = TRUE;
-      else if (!gnutls->priv->construct_error)
-	{
-	  gnutls->priv->construct_error =
-	    g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
-			 _("Could not parse DER certificate: %s"),
-			 gnutls_strerror (status));
-	}
+        priv->have_cert = TRUE;
+      else if (!priv->construct_error)
+        {
+          priv->construct_error =
+            g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
+                         _("Could not parse DER certificate: %s"),
+                         gnutls_strerror (status));
+        }
 
       break;
 
     case PROP_CERTIFICATE_PEM:
       string = g_value_get_string (value);
       if (!string)
-	break;
-      g_return_if_fail (gnutls->priv->have_cert == FALSE);
+        break;
+      g_return_if_fail (priv->have_cert == FALSE);
       data.data = (void *)string;
       data.size = strlen (string);
-      status = gnutls_x509_crt_import (gnutls->priv->cert, &data,
-				       GNUTLS_X509_FMT_PEM);
+      status = gnutls_x509_crt_import (priv->cert, &data,
+                                       GNUTLS_X509_FMT_PEM);
       if (status == 0)
-	gnutls->priv->have_cert = TRUE;
-      else if (!gnutls->priv->construct_error)
-	{
-	  gnutls->priv->construct_error =
-	    g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
-			 _("Could not parse PEM certificate: %s"),
-			 gnutls_strerror (status));
-	}
+        priv->have_cert = TRUE;
+      else if (!priv->construct_error)
+        {
+          priv->construct_error =
+            g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
+                         _("Could not parse PEM certificate: %s"),
+                         gnutls_strerror (status));
+        }
       break;
 
     case PROP_PRIVATE_KEY:
       bytes = g_value_get_boxed (value);
       if (!bytes)
-	break;
-      g_return_if_fail (gnutls->priv->have_key == FALSE);
+        break;
+      g_return_if_fail (priv->have_key == FALSE);
       data.data = bytes->data;
       data.size = bytes->len;
-      if (!gnutls->priv->key)
-        gnutls_x509_privkey_init (&gnutls->priv->key);
-      status = gnutls_x509_privkey_import (gnutls->priv->key, &data,
-					   GNUTLS_X509_FMT_DER);
+      if (!priv->key)
+        gnutls_x509_privkey_init (&priv->key);
+      status = gnutls_x509_privkey_import (priv->key, &data,
+                                           GNUTLS_X509_FMT_DER);
       if (status != 0)
-	{
-	  int pkcs8_status =
-	    gnutls_x509_privkey_import_pkcs8 (gnutls->priv->key, &data,
-					      GNUTLS_X509_FMT_DER, NULL,
-					      GNUTLS_PKCS_PLAIN);
-	  if (pkcs8_status == 0)
-	    status = 0;
-	}
+        {
+          int pkcs8_status =
+            gnutls_x509_privkey_import_pkcs8 (priv->key, &data,
+                                              GNUTLS_X509_FMT_DER, NULL,
+                                              GNUTLS_PKCS_PLAIN);
+          if (pkcs8_status == 0)
+            status = 0;
+        }
       if (status == 0)
-	gnutls->priv->have_key = TRUE;
-      else if (!gnutls->priv->construct_error)
-	{
-	  gnutls->priv->construct_error =
-	    g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
-			 _("Could not parse DER private key: %s"),
-			 gnutls_strerror (status));
-	}
+        priv->have_key = TRUE;
+      else if (!priv->construct_error)
+        {
+          priv->construct_error =
+            g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
+                         _("Could not parse DER private key: %s"),
+                         gnutls_strerror (status));
+        }
       break;
 
     case PROP_PRIVATE_KEY_PEM:
       string = g_value_get_string (value);
       if (!string)
-	break;
-      g_return_if_fail (gnutls->priv->have_key == FALSE);
+        break;
+      g_return_if_fail (priv->have_key == FALSE);
       data.data = (void *)string;
       data.size = strlen (string);
-      if (!gnutls->priv->key)
-        gnutls_x509_privkey_init (&gnutls->priv->key);
-      status = gnutls_x509_privkey_import (gnutls->priv->key, &data,
-					   GNUTLS_X509_FMT_PEM);
+      if (!priv->key)
+        gnutls_x509_privkey_init (&priv->key);
+      status = gnutls_x509_privkey_import (priv->key, &data,
+                                           GNUTLS_X509_FMT_PEM);
       if (status != 0)
-	{
-	  int pkcs8_status =
-	    gnutls_x509_privkey_import_pkcs8 (gnutls->priv->key, &data,
-					      GNUTLS_X509_FMT_PEM, NULL,
-					      GNUTLS_PKCS_PLAIN);
-	  if (pkcs8_status == 0)
-	    status = 0;
-	}
+        {
+          int pkcs8_status =
+            gnutls_x509_privkey_import_pkcs8 (priv->key, &data,
+                                              GNUTLS_X509_FMT_PEM, NULL,
+                                              GNUTLS_PKCS_PLAIN);
+          if (pkcs8_status == 0)
+            status = 0;
+        }
       if (status == 0)
-	gnutls->priv->have_key = TRUE;
-      else if (!gnutls->priv->construct_error)
-	{
-	  gnutls->priv->construct_error =
-	    g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
-			 _("Could not parse PEM private key: %s"),
-			 gnutls_strerror (status));
-	}
+        priv->have_key = TRUE;
+      else if (!priv->construct_error)
+        {
+          priv->construct_error =
+            g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
+                         _("Could not parse PEM private key: %s"),
+                         gnutls_strerror (status));
+        }
       break;
 
     case PROP_ISSUER:
-      gnutls->priv->issuer = g_value_dup_object (value);
+      priv->issuer = g_value_dup_object (value);
       break;
 
     default:
@@ -273,30 +279,29 @@ g_tls_certificate_gnutls_set_property (GObject      *object,
 static void
 g_tls_certificate_gnutls_init (GTlsCertificateGnutls *gnutls)
 {
-  gnutls->priv = G_TYPE_INSTANCE_GET_PRIVATE (gnutls,
-					      G_TYPE_TLS_CERTIFICATE_GNUTLS,
-					      GTlsCertificateGnutlsPrivate);
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
 
-  gnutls_x509_crt_init (&gnutls->priv->cert);
+  gnutls_x509_crt_init (&priv->cert);
 }
 
 static gboolean
 g_tls_certificate_gnutls_initable_init (GInitable       *initable,
-					GCancellable    *cancellable,
-					GError         **error)
+                                        GCancellable    *cancellable,
+                                        GError         **error)
 {
   GTlsCertificateGnutls *gnutls = G_TLS_CERTIFICATE_GNUTLS (initable);
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
 
-  if (gnutls->priv->construct_error)
+  if (priv->construct_error)
     {
-      g_propagate_error (error, gnutls->priv->construct_error);
-      gnutls->priv->construct_error = NULL;
+      g_propagate_error (error, priv->construct_error);
+      priv->construct_error = NULL;
       return FALSE;
     }
-  else if (!gnutls->priv->have_cert)
+  else if (!priv->have_cert)
     {
       g_set_error_literal (error, G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
-			   _("No certificate data provided"));
+                           _("No certificate data provided"));
       return FALSE;
     }
   else
@@ -305,8 +310,8 @@ g_tls_certificate_gnutls_initable_init (GInitable       *initable,
 
 static GTlsCertificateFlags
 g_tls_certificate_gnutls_verify (GTlsCertificate     *cert,
-				 GSocketConnectable  *identity,
-				 GTlsCertificate     *trusted_ca)
+                                 GSocketConnectable  *identity,
+                                 GTlsCertificate     *trusted_ca)
 {
   GTlsCertificateGnutls *cert_gnutls;
   guint num_certs, i;
@@ -315,30 +320,43 @@ g_tls_certificate_gnutls_verify (GTlsCertificate     *cert,
   time_t t, now;
 
   cert_gnutls = G_TLS_CERTIFICATE_GNUTLS (cert);
-  for (num_certs = 0; cert_gnutls; cert_gnutls = cert_gnutls->priv->issuer)
-    num_certs++;
+  num_certs = 0;
+  do
+    {
+      GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (cert_gnutls);
+      cert_gnutls = priv->issuer;
+      num_certs++;
+    }
+  while (cert_gnutls);
+
   chain = g_new (gnutls_x509_crt_t, num_certs);
   cert_gnutls = G_TLS_CERTIFICATE_GNUTLS (cert);
-  for (i = 0; cert_gnutls; cert_gnutls = cert_gnutls->priv->issuer, i++)
-    chain[i] = cert_gnutls->priv->cert;
+  for (i = 0; i < num_certs; i++)
+    {
+      GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (cert_gnutls);
+      chain[i] = priv->cert;
+      cert_gnutls = priv->issuer;
+    }
+  g_assert (!cert_gnutls);
 
   if (trusted_ca)
     {
+      GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (G_TLS_CERTIFICATE_GNUTLS (trusted_ca));
       gnutls_x509_crt_t ca;
       guint gnutls_flags;
       int status;
 
-      ca = G_TLS_CERTIFICATE_GNUTLS (trusted_ca)->priv->cert;
+      ca = priv->cert;
       status = gnutls_x509_crt_list_verify (chain, num_certs,
-					    &ca, 1,
-					    NULL, 0,
-					    GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT,
-					    &gnutls_flags);
+                                            &ca, 1,
+                                            NULL, 0,
+                                            GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT,
+                                            &gnutls_flags);
       if (status != 0)
-	{
-	  g_free (chain);
-	  return G_TLS_CERTIFICATE_GENERIC_ERROR;
-	}
+        {
+          g_free (chain);
+          return G_TLS_CERTIFICATE_GENERIC_ERROR;
+        }
 
       gtls_flags = g_tls_certificate_gnutls_convert_flags (gnutls_flags);
     }
@@ -353,11 +371,11 @@ g_tls_certificate_gnutls_verify (GTlsCertificate     *cert,
     {
       t = gnutls_x509_crt_get_activation_time (chain[i]);
       if (t == (time_t) -1 || t > now)
-	gtls_flags |= G_TLS_CERTIFICATE_NOT_ACTIVATED;
+        gtls_flags |= G_TLS_CERTIFICATE_NOT_ACTIVATED;
 
       t = gnutls_x509_crt_get_expiration_time (chain[i]);
       if (t == (time_t) -1 || t < now)
-	gtls_flags |= G_TLS_CERTIFICATE_EXPIRED;
+        gtls_flags |= G_TLS_CERTIFICATE_EXPIRED;
     }
 
   g_free (chain);
@@ -386,8 +404,9 @@ g_tls_certificate_gnutls_real_copy (GTlsCertificateGnutls    *gnutls,
   chain = gnutls;
   while (chain != NULL)
     {
+      GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (chain);
       num_certs++;
-      chain = chain->priv->issuer;
+      chain = priv->issuer;
     }
 
   st->ncerts = 0;
@@ -397,11 +416,13 @@ g_tls_certificate_gnutls_real_copy (GTlsCertificateGnutls    *gnutls,
   chain = gnutls;
   while (chain != NULL)
     {
-      gnutls_x509_crt_export (chain->priv->cert, GNUTLS_X509_FMT_DER,
+      GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (chain);
+
+      gnutls_x509_crt_export (priv->cert, GNUTLS_X509_FMT_DER,
                               NULL, &size);
       data.data = g_malloc (size);
       data.size = size;
-      gnutls_x509_crt_export (chain->priv->cert, GNUTLS_X509_FMT_DER,
+      gnutls_x509_crt_export (priv->cert, GNUTLS_X509_FMT_DER,
                               data.data, &size);
 
       gnutls_x509_crt_init (&cert);
@@ -412,14 +433,18 @@ g_tls_certificate_gnutls_real_copy (GTlsCertificateGnutls    *gnutls,
       st->cert.x509[st->ncerts] = cert;
       st->ncerts++;
 
-      chain = chain->priv->issuer;
+      chain = priv->issuer;
     }
 
-  if (gnutls->priv->key != NULL)
     {
-      gnutls_x509_privkey_init (&st->key.x509);
-      gnutls_x509_privkey_cpy (st->key.x509, gnutls->priv->key);
-      st->key_type = GNUTLS_PRIVKEY_X509;
+      GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
+
+      if (priv->key != NULL)
+        {
+          gnutls_x509_privkey_init (&st->key.x509);
+          gnutls_x509_privkey_cpy (st->key.x509, priv->key);
+          st->key_type = GNUTLS_PRIVKEY_X509;
+        }
     }
 
   st->deinit_all = TRUE;
@@ -431,8 +456,6 @@ g_tls_certificate_gnutls_class_init (GTlsCertificateGnutlsClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GTlsCertificateClass *certificate_class = G_TLS_CERTIFICATE_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GTlsCertificateGnutlsPrivate));
-
   gobject_class->get_property = g_tls_certificate_gnutls_get_property;
   gobject_class->set_property = g_tls_certificate_gnutls_set_property;
   gobject_class->finalize     = g_tls_certificate_gnutls_finalize;
@@ -456,13 +479,13 @@ g_tls_certificate_gnutls_initable_iface_init (GInitableIface  *iface)
 
 GTlsCertificate *
 g_tls_certificate_gnutls_new (const gnutls_datum_t *datum,
-			      GTlsCertificate      *issuer)
+                              GTlsCertificate      *issuer)
 {
   GTlsCertificateGnutls *gnutls;
 
   gnutls = g_object_new (G_TYPE_TLS_CERTIFICATE_GNUTLS,
-			 "issuer", issuer,
-			 NULL);
+                         "issuer", issuer,
+                         NULL);
   g_tls_certificate_gnutls_set_data (gnutls, datum);
 
   return G_TLS_CERTIFICATE (gnutls);
@@ -472,24 +495,30 @@ void
 g_tls_certificate_gnutls_set_data (GTlsCertificateGnutls *gnutls,
                                    const gnutls_datum_t  *datum)
 {
-  g_return_if_fail (G_IS_TLS_CERTIFICATE_GNUTLS (gnutls));
-  g_return_if_fail (!gnutls->priv->have_cert);
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
 
-  if (gnutls_x509_crt_import (gnutls->priv->cert, datum,
+  g_return_if_fail (G_IS_TLS_CERTIFICATE_GNUTLS (gnutls));
+  g_return_if_fail (!priv->have_cert);
+
+  if (gnutls_x509_crt_import (priv->cert, datum,
                               GNUTLS_X509_FMT_DER) == 0)
-    gnutls->priv->have_cert = TRUE;
+    priv->have_cert = TRUE;
 }
 
 const gnutls_x509_crt_t
 g_tls_certificate_gnutls_get_cert (GTlsCertificateGnutls *gnutls)
 {
-  return gnutls->priv->cert;
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
+
+  return priv->cert;
 }
 
 gboolean
 g_tls_certificate_gnutls_has_key (GTlsCertificateGnutls *gnutls)
 {
-  return gnutls->priv->have_key;
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
+
+  return priv->have_key;
 }
 
 void
@@ -535,10 +564,10 @@ g_tls_certificate_gnutls_convert_flags (guint gnutls_flags)
   for (i = 0; i < flags_map_size && gnutls_flags != 0; i++)
     {
       if (gnutls_flags & flags_map[i].gnutls_flag)
-	{
-	  gnutls_flags &= ~flags_map[i].gnutls_flag;
-	  gtls_flags |= flags_map[i].gtls_flag;
-	}
+        {
+          gnutls_flags &= ~flags_map[i].gnutls_flag;
+          gtls_flags |= flags_map[i].gtls_flag;
+        }
     }
   if (gnutls_flags)
     gtls_flags |= G_TLS_CERTIFICATE_GENERIC_ERROR;
@@ -548,8 +577,9 @@ g_tls_certificate_gnutls_convert_flags (guint gnutls_flags)
 
 static gboolean
 verify_identity_hostname (GTlsCertificateGnutls *gnutls,
-			  GSocketConnectable    *identity)
+                          GSocketConnectable    *identity)
 {
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
   const char *hostname;
 
   if (G_IS_NETWORK_ADDRESS (identity))
@@ -559,13 +589,14 @@ verify_identity_hostname (GTlsCertificateGnutls *gnutls,
   else
     return FALSE;
 
-  return gnutls_x509_crt_check_hostname (gnutls->priv->cert, hostname);
+  return gnutls_x509_crt_check_hostname (priv->cert, hostname);
 }
 
 static gboolean
 verify_identity_ip (GTlsCertificateGnutls *gnutls,
-		    GSocketConnectable    *identity)
+                    GSocketConnectable    *identity)
 {
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
   GInetAddress *addr;
   int i, ret = 0;
   gsize addr_size;
@@ -597,17 +628,17 @@ verify_identity_ip (GTlsCertificateGnutls *gnutls,
       size_t san_size;
 
       san_size = sizeof (san);
-      ret = gnutls_x509_crt_get_subject_alt_name (gnutls->priv->cert, i,
-						  san, &san_size, NULL);
+      ret = gnutls_x509_crt_get_subject_alt_name (priv->cert, i,
+                                                  san, &san_size, NULL);
 
       if ((ret == GNUTLS_SAN_IPADDRESS) && (addr_size == san_size))
-	{
-	  if (memcmp (addr_bytes, san, addr_size) == 0)
-	    {
-	      g_object_unref (addr);
-	      return TRUE;
-	    }
-	}
+        {
+          if (memcmp (addr_bytes, san, addr_size) == 0)
+            {
+              g_object_unref (addr);
+              return TRUE;
+            }
+        }
     }
 
   g_object_unref (addr);
@@ -616,7 +647,7 @@ verify_identity_ip (GTlsCertificateGnutls *gnutls,
 
 GTlsCertificateFlags
 g_tls_certificate_gnutls_verify_identity (GTlsCertificateGnutls *gnutls,
-					  GSocketConnectable    *identity)
+                                          GSocketConnectable    *identity)
 {
   if (verify_identity_hostname (gnutls, identity))
     return 0;
@@ -634,14 +665,16 @@ void
 g_tls_certificate_gnutls_set_issuer (GTlsCertificateGnutls *gnutls,
                                      GTlsCertificateGnutls *issuer)
 {
+  GTlsCertificateGnutlsPrivate *priv = g_tls_certificate_gnutls_get_instance_private (gnutls);
+
   g_return_if_fail (G_IS_TLS_CERTIFICATE_GNUTLS (gnutls));
   g_return_if_fail (!issuer || G_IS_TLS_CERTIFICATE_GNUTLS (issuer));
 
   if (issuer)
     g_object_ref (issuer);
-  if (gnutls->priv->issuer)
-    g_object_unref (gnutls->priv->issuer);
-  gnutls->priv->issuer = issuer;
+  if (priv->issuer)
+    g_object_unref (priv->issuer);
+  priv->issuer = issuer;
   g_object_notify (G_OBJECT (gnutls), "issuer");
 }
 
