@@ -1,4 +1,6 @@
-/* GIO - GLib Input, Output and Streaming Library
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/*
+ * GIO - GLib Input, Output and Streaming Library
  *
  * Copyright 2010 Red Hat, Inc.
  *
@@ -23,23 +25,25 @@
 #include "config.h"
 #include "gtlsinputstream-gnutls.h"
 
+struct _GTlsInputStreamGnutls
+{
+  GInputStream parent_instance;
+
+  GWeakRef weak_conn;
+};
+
 static void g_tls_input_stream_gnutls_pollable_iface_init (GPollableInputStreamInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GTlsInputStreamGnutls, g_tls_input_stream_gnutls, G_TYPE_INPUT_STREAM,
-			 G_IMPLEMENT_INTERFACE (G_TYPE_POLLABLE_INPUT_STREAM, g_tls_input_stream_gnutls_pollable_iface_init)
-			 )
-
-struct _GTlsInputStreamGnutlsPrivate
-{
-  GWeakRef weak_conn;
-};
+                         G_IMPLEMENT_INTERFACE (G_TYPE_POLLABLE_INPUT_STREAM, g_tls_input_stream_gnutls_pollable_iface_init)
+                         )
 
 static void
 g_tls_input_stream_gnutls_dispose (GObject *object)
 {
   GTlsInputStreamGnutls *stream = G_TLS_INPUT_STREAM_GNUTLS (object);
 
-  g_weak_ref_set (&stream->priv->weak_conn, NULL);
+  g_weak_ref_set (&stream->weak_conn, NULL);
 
   G_OBJECT_CLASS (g_tls_input_stream_gnutls_parent_class)->dispose (object);
 }
@@ -49,23 +53,23 @@ g_tls_input_stream_gnutls_finalize (GObject *object)
 {
   GTlsInputStreamGnutls *stream = G_TLS_INPUT_STREAM_GNUTLS (object);
 
-  g_weak_ref_clear (&stream->priv->weak_conn);
+  g_weak_ref_clear (&stream->weak_conn);
 
   G_OBJECT_CLASS (g_tls_input_stream_gnutls_parent_class)->finalize (object);
 }
 
 static gssize
 g_tls_input_stream_gnutls_read (GInputStream  *stream,
-				void          *buffer,
-				gsize          count,
-				GCancellable  *cancellable,
-				GError       **error)
+                                void          *buffer,
+                                gsize          count,
+                                GCancellable  *cancellable,
+                                GError       **error)
 {
   GTlsInputStreamGnutls *tls_stream = G_TLS_INPUT_STREAM_GNUTLS (stream);
   GTlsConnectionGnutls *conn;
   gssize ret;
 
-  conn = g_weak_ref_get (&tls_stream->priv->weak_conn);
+  conn = g_weak_ref_get (&tls_stream->weak_conn);
   g_return_val_if_fail (conn != NULL, -1);
 
   ret = g_tls_connection_gnutls_read (conn,
@@ -82,7 +86,7 @@ g_tls_input_stream_gnutls_pollable_is_readable (GPollableInputStream *pollable)
   GTlsConnectionGnutls *conn;
   gboolean ret;
 
-  conn = g_weak_ref_get (&tls_stream->priv->weak_conn);
+  conn = g_weak_ref_get (&tls_stream->weak_conn);
   g_return_val_if_fail (conn != NULL, FALSE);
 
   ret = g_tls_connection_gnutls_check (conn, G_IO_IN);
@@ -93,13 +97,13 @@ g_tls_input_stream_gnutls_pollable_is_readable (GPollableInputStream *pollable)
 
 static GSource *
 g_tls_input_stream_gnutls_pollable_create_source (GPollableInputStream *pollable,
-						  GCancellable         *cancellable)
+                                                  GCancellable         *cancellable)
 {
   GTlsInputStreamGnutls *tls_stream = G_TLS_INPUT_STREAM_GNUTLS (pollable);
   GTlsConnectionGnutls *conn;
   GSource *ret;
 
-  conn = g_weak_ref_get (&tls_stream->priv->weak_conn);
+  conn = g_weak_ref_get (&tls_stream->weak_conn);
   g_return_val_if_fail (conn != NULL, NULL);
 
   ret = g_tls_connection_gnutls_create_source (conn, G_IO_IN, cancellable);
@@ -109,15 +113,15 @@ g_tls_input_stream_gnutls_pollable_create_source (GPollableInputStream *pollable
 
 static gssize
 g_tls_input_stream_gnutls_pollable_read_nonblocking (GPollableInputStream  *pollable,
-						     void                  *buffer,
-						     gsize                  size,
-						     GError               **error)
+                                                     void                  *buffer,
+                                                     gsize                  size,
+                                                     GError               **error)
 {
   GTlsInputStreamGnutls *tls_stream = G_TLS_INPUT_STREAM_GNUTLS (pollable);
   GTlsConnectionGnutls *conn;
   gssize ret;
 
-  conn = g_weak_ref_get (&tls_stream->priv->weak_conn);
+  conn = g_weak_ref_get (&tls_stream->weak_conn);
   g_return_val_if_fail (conn != NULL, -1);
 
   ret = g_tls_connection_gnutls_read (conn, buffer, size,
@@ -136,7 +140,7 @@ g_tls_input_stream_gnutls_close (GInputStream            *stream,
   GIOStream *conn;
   gboolean ret;
 
-  conn = g_weak_ref_get (&tls_stream->priv->weak_conn);
+  conn = g_weak_ref_get (&tls_stream->weak_conn);
 
   /* Special case here because this is called by the finalize
    * of the main GTlsConnection object.
@@ -166,7 +170,7 @@ close_thread (GTask        *task,
   GError *error = NULL;
   GIOStream *conn;
 
-  conn = g_weak_ref_get (&tls_stream->priv->weak_conn);
+  conn = g_weak_ref_get (&tls_stream->weak_conn);
 
   if (conn && !g_tls_connection_gnutls_close_internal (conn,
                                                        G_TLS_DIRECTION_READ,
@@ -215,8 +219,6 @@ g_tls_input_stream_gnutls_class_init (GTlsInputStreamGnutlsClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GInputStreamClass *input_stream_class = G_INPUT_STREAM_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GTlsInputStreamGnutlsPrivate));
-
   gobject_class->dispose = g_tls_input_stream_gnutls_dispose;
   gobject_class->finalize = g_tls_input_stream_gnutls_finalize;
 
@@ -237,7 +239,6 @@ g_tls_input_stream_gnutls_pollable_iface_init (GPollableInputStreamInterface *if
 static void
 g_tls_input_stream_gnutls_init (GTlsInputStreamGnutls *stream)
 {
-  stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (stream, G_TYPE_TLS_INPUT_STREAM_GNUTLS, GTlsInputStreamGnutlsPrivate);
 }
 
 GInputStream *
@@ -246,7 +247,7 @@ g_tls_input_stream_gnutls_new (GTlsConnectionGnutls *conn)
   GTlsInputStreamGnutls *tls_stream;
 
   tls_stream = g_object_new (G_TYPE_TLS_INPUT_STREAM_GNUTLS, NULL);
-  g_weak_ref_init (&tls_stream->priv->weak_conn, conn);
+  g_weak_ref_init (&tls_stream->weak_conn, conn);
 
   return G_INPUT_STREAM (tls_stream);
 }
