@@ -1,4 +1,6 @@
-/* GIO - GLib Input, Output and Streaming Library
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/*
+ * GIO - GLib Input, Output and Streaming Library
  *
  * Copyright 2010 Red Hat, Inc
  *
@@ -38,6 +40,13 @@ enum
   PROP_AUTHENTICATION_MODE
 };
 
+struct _GTlsServerConnectionGnutls
+{
+  GTlsConnectionGnutls parent_instance;
+
+  GTlsAuthenticationMode authentication_mode;
+};
+
 static void     g_tls_server_connection_gnutls_initable_interface_init (GInitableIface  *iface);
 
 static void g_tls_server_connection_gnutls_server_connection_interface_init (GTlsServerConnectionInterface *iface);
@@ -50,44 +59,37 @@ static int g_tls_server_connection_gnutls_retrieve_function (gnutls_session_t
                                                              gnutls_retr2_st             *st);
 
 static int            g_tls_server_connection_gnutls_db_store    (void            *user_data,
-								  gnutls_datum_t   key,
-								  gnutls_datum_t   data);
+                                                                  gnutls_datum_t   key,
+                                                                  gnutls_datum_t   data);
 static int            g_tls_server_connection_gnutls_db_remove   (void            *user_data,
-								  gnutls_datum_t   key);
+                                                                  gnutls_datum_t   key);
 static gnutls_datum_t g_tls_server_connection_gnutls_db_retrieve (void            *user_data,
-								  gnutls_datum_t   key);
+                                                                  gnutls_datum_t   key);
 
 static GInitableIface *g_tls_server_connection_gnutls_parent_initable_iface;
 
 G_DEFINE_TYPE_WITH_CODE (GTlsServerConnectionGnutls, g_tls_server_connection_gnutls, G_TYPE_TLS_CONNECTION_GNUTLS,
-			 G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
-						g_tls_server_connection_gnutls_initable_interface_init)
-			 G_IMPLEMENT_INTERFACE (G_TYPE_TLS_SERVER_CONNECTION,
-						g_tls_server_connection_gnutls_server_connection_interface_init)
+                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
+                                                g_tls_server_connection_gnutls_initable_interface_init)
+                         G_IMPLEMENT_INTERFACE (G_TYPE_TLS_SERVER_CONNECTION,
+                                                g_tls_server_connection_gnutls_server_connection_interface_init)
                          G_IMPLEMENT_INTERFACE (G_TYPE_DTLS_SERVER_CONNECTION,
                                                 NULL)
 )
 
-struct _GTlsServerConnectionGnutlsPrivate
-{
-  GTlsAuthenticationMode authentication_mode;
-};
-
 static void
 g_tls_server_connection_gnutls_init (GTlsServerConnectionGnutls *gnutls)
 {
   gnutls_certificate_credentials_t creds;
 
-  gnutls->priv = G_TYPE_INSTANCE_GET_PRIVATE (gnutls, G_TYPE_TLS_SERVER_CONNECTION_GNUTLS, GTlsServerConnectionGnutlsPrivate);
-
   creds = g_tls_connection_gnutls_get_credentials (G_TLS_CONNECTION_GNUTLS (gnutls));
   gnutls_certificate_set_retrieve_function (creds, g_tls_server_connection_gnutls_retrieve_function);
 }
 
 static gboolean
 g_tls_server_connection_gnutls_initable_init (GInitable       *initable,
-					      GCancellable    *cancellable,
-					      GError         **error)
+                                              GCancellable    *cancellable,
+                                              GError         **error)
 {
   GTlsConnectionGnutls *gnutls = G_TLS_CONNECTION_GNUTLS (initable);
   GTlsCertificate *cert;
@@ -106,7 +108,7 @@ g_tls_server_connection_gnutls_initable_init (GInitable       *initable,
   if (cert && !g_tls_certificate_gnutls_has_key (G_TLS_CERTIFICATE_GNUTLS (cert)))
     {
       g_set_error_literal (error, G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
-			   _("Certificate has no private key"));
+                           _("Certificate has no private key"));
       return FALSE;
     }
 
@@ -115,16 +117,16 @@ g_tls_server_connection_gnutls_initable_init (GInitable       *initable,
 
 static void
 g_tls_server_connection_gnutls_get_property (GObject    *object,
-					     guint       prop_id,
-					     GValue     *value,
-					     GParamSpec *pspec)
+                                             guint       prop_id,
+                                             GValue     *value,
+                                             GParamSpec *pspec)
 {
   GTlsServerConnectionGnutls *gnutls = G_TLS_SERVER_CONNECTION_GNUTLS (object);
 
   switch (prop_id)
     {
     case PROP_AUTHENTICATION_MODE:
-      g_value_set_enum (value, gnutls->priv->authentication_mode);
+      g_value_set_enum (value, gnutls->authentication_mode);
       break;
       
     default:
@@ -134,16 +136,16 @@ g_tls_server_connection_gnutls_get_property (GObject    *object,
 
 static void
 g_tls_server_connection_gnutls_set_property (GObject      *object,
-					     guint         prop_id,
-					     const GValue *value,
-					     GParamSpec   *pspec)
+                                             guint         prop_id,
+                                             const GValue *value,
+                                             GParamSpec   *pspec)
 {
   GTlsServerConnectionGnutls *gnutls = G_TLS_SERVER_CONNECTION_GNUTLS (object);
 
   switch (prop_id)
     {
     case PROP_AUTHENTICATION_MODE:
-      gnutls->priv->authentication_mode = g_value_get_enum (value);
+      gnutls->authentication_mode = g_value_get_enum (value);
       break;
 
     default:
@@ -176,7 +178,7 @@ g_tls_server_connection_gnutls_begin_handshake (GTlsConnectionGnutls *conn)
   gnutls_session_t session;
   gnutls_certificate_request_t req_mode;
 
-  switch (gnutls->priv->authentication_mode)
+  switch (gnutls->authentication_mode)
     {
     case G_TLS_AUTHENTICATION_REQUESTED:
       req_mode = GNUTLS_CERT_REQUEST;
@@ -196,7 +198,7 @@ g_tls_server_connection_gnutls_begin_handshake (GTlsConnectionGnutls *conn)
 
 static void
 g_tls_server_connection_gnutls_finish_handshake (GTlsConnectionGnutls  *gnutls,
-						 GError               **inout_error)
+                                                 GError               **inout_error)
 {
 }
 
@@ -204,8 +206,8 @@ g_tls_server_connection_gnutls_finish_handshake (GTlsConnectionGnutls  *gnutls,
 
 static int
 g_tls_server_connection_gnutls_db_store (void            *user_data,
-					 gnutls_datum_t   key,
-					 gnutls_datum_t   data)
+                                         gnutls_datum_t   key,
+                                         gnutls_datum_t   data)
 {
   GBytes *session_id, *session_data;
 
@@ -220,7 +222,7 @@ g_tls_server_connection_gnutls_db_store (void            *user_data,
 
 static int
 g_tls_server_connection_gnutls_db_remove (void            *user_data,
-					  gnutls_datum_t   key)
+                                          gnutls_datum_t   key)
 {
   GBytes *session_id;
 
@@ -233,7 +235,7 @@ g_tls_server_connection_gnutls_db_remove (void            *user_data,
 
 static gnutls_datum_t
 g_tls_server_connection_gnutls_db_retrieve (void            *user_data,
-					    gnutls_datum_t   key)
+                                            gnutls_datum_t   key)
 {
   GBytes *session_id, *session_data;
   gnutls_datum_t data;
@@ -264,8 +266,6 @@ g_tls_server_connection_gnutls_class_init (GTlsServerConnectionGnutlsClass *klas
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GTlsConnectionGnutlsClass *connection_gnutls_class = G_TLS_CONNECTION_GNUTLS_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GTlsServerConnectionGnutlsPrivate));
-
   gobject_class->get_property = g_tls_server_connection_gnutls_get_property;
   gobject_class->set_property = g_tls_server_connection_gnutls_set_property;
 
