@@ -5,6 +5,8 @@ msg() {
   echo "* $1 ..."
 }
 
+cd `dirname $0`
+
 echo
 echo "This script re-generates all private keys and certificates"
 echo "needed to run the Unit Test."
@@ -22,7 +24,7 @@ echo "the contents of ca.pem."
 echo
 echo "Also, file-database.c:test_lookup_certificates_issued_by has"
 echo "an ISSUER variable that needs to be changed by the CA identifier"
-echo "(read the comment in that function)."
+echo "(read the comment in that function) if you modify this script."
 echo
 echo "                   *** IMPORTANT ***"
 echo
@@ -30,17 +32,37 @@ echo
 read -p "Press [Enter] key to continue..." key
 
 #######################################################################
-### Root CA
+### Obsolete/Untrusted Root CA
 #######################################################################
 
 echo "00" > serial
 
+msg "Creating CA private key for obsolete/untrusted CA"
+openssl genrsa -out old-ca-key.pem 1024
+
+msg "Creating CA certificate for obsolete/untrusted CA"
+openssl req -x509 -new -config ssl/old-ca.conf -days 10950 -key old-ca-key.pem -out old-ca.pem
+
+#######################################################################
+### New Root CA
+#######################################################################
+
 msg "Creating CA private key"
 openssl genrsa -out ca-key.pem 1024
 
 msg "Creating CA certificate"
 openssl req -x509 -new -config ssl/ca.conf -days 10950 -key ca-key.pem -out ca.pem
 
+#######################################################################
+### New Root CA, issued by Obsolete/Untrusted Root CA
+#######################################################################
+
+msg "Creating CA certificate request"
+openssl req -config ssl/ca.conf -key ca-key.pem -new -out root-ca-csr.pem
+
+msg "Creating alternative certificate with same keys as CA"
+openssl x509 -req -in root-ca-csr.pem -days 10950 -CA old-ca.pem -CAkey old-ca-key.pem -CAserial serial -extfile ssl/ca.conf -extensions v3_req_ext -out ca-alternative.pem
+
 #######################################################################
 ### Server
 #######################################################################
@@ -102,6 +124,14 @@ openssl x509 -req -in client-csr.pem -days 365 -startdate -enddate -CA ca.pem -C
 sudo hwclock -s
 touch client-future.pem
 
+msg "Creating second client key pair"
+openssl genrsa -out client2-key.pem 2048
+openssl req -config ssl/client.conf -key client2-key.pem -new -out client2-csr.pem
+openssl x509 -req -in client2-csr.pem -days 9125 -CA ca.pem -CAkey ca-key.pem -CAserial serial -out client2.pem
+
+msg "Concatenating second client certificate and private key into a single file"
+cat client2.pem client2-key.pem > client2-and-key.pem
+
 #######################################################################
 ### Concatenate all non-CA certificates
 #######################################################################
